@@ -25,5 +25,5 @@ run_job(
     }
 );
 
-exit;
+1;
 
